
.. _reference:

================
Numina Reference
================

:Release: |version|

:Date: |today|

.. warning::

   This "Reference" is still a work in progress; some of the material
   is not organized, and several aspects of Numina are not yet covered
   sufficient detail.

.. module:: numina

.. toctree::
   :maxdepth: 2

   modules

   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
